"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = void 0;
var fs_extra_1 = __importDefault(require("fs-extra"));
var path_1 = __importDefault(require("path"));
var commands_1 = require("../commands");
var config_1 = require("../config");
var logs_1 = require("../logs");
var paths_1 = require("../paths");
var projects_1 = require("../projects");
function execute(args) {
    var log = console.log, debug = console.debug, error = console.error;
    logs_1.h1("Project creation");
    var config = config_1.getConfig();
    if (args._[1] == undefined) {
        throw new commands_1.OrigeenError("You need to provide a project name", [
            "Add a <projectName> after the command name",
        ]);
    }
    if (config.workspace == undefined) {
        throw new commands_1.OrigeenError("You did not configure your workspace location yet", [
            "Run 'orgn setup' if you haven't done it yet",
            "Run 'orgn config workspace --set <pathToWorkspace>",
        ]);
    }
    var pathToProject = path_1.default.join(config.workspace, args._[1]);
    var pathToProjectSegments = pathToProject.split("\\");
    var projectName = pathToProjectSegments[pathToProjectSegments.length - 1];
    debug("New Project name :");
    debug(projectName);
    debug();
    debug("Absolute path to project :");
    debug(pathToProject);
    debug();
    var projects = projects_1.getProjects();
    var alreadyExist = projects.some(function (project) { return project.name === projectName; });
    if (alreadyExist) {
        throw new commands_1.OrigeenError("You can't create two projects with the name. '" + projectName + "' is already used.", [
            "Choose another name",
            "Check the spelling",
            "Delete the existing project",
        ]);
    }
    projects.forEach(function (project) {
        if (project.path.includes(pathToProject) ||
            pathToProject.includes(project.path)) {
            throw new commands_1.OrigeenError("Origeen doesn't support sub-projects\n" +
                ("The given path '" + pathToProject + "' relates\nsomehow to '" + project.path + "' in a unsupported way.\n") +
                "Such a project structur would cause incovenience.", [
                "Check the spelling of the path",
                "Think of another location for the project",
                "Delete the other project",
            ]);
        }
    });
    var templateName = args.template || "@empty";
    debug("Template name: '" + templateName + "'");
    debug();
    var templatePath = path_1.default.join(paths_1.TEMPLATES, templateName);
    debug("Absolute path to template :");
    debug(templatePath);
    debug();
    log("Creating project '" + projectName + "'");
    log("At '" + pathToProject + "'");
    log("Using template '" + templateName + "'");
    log();
    debug("Copying template to the project destination");
    fs_extra_1.default.copySync(templatePath, pathToProject);
    debug("Copied!");
    debug();
    debug("Adding new project to 'projects.json'");
    projects_1.addProject({ name: projectName, path: pathToProject });
    debug("Added!");
    debug();
    log("Done!");
}
exports.execute = execute;
