"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.execute = void 0;
var child_process_1 = require("child_process");
var projects_1 = require("../projects");
var config_1 = require("../config");
var logs_1 = require("../logs");
var commands_1 = require("../commands");
function execute(args) {
    var _a;
    var debug = console.debug, log = console.log, error = console.error;
    logs_1.h1("Project Opening");
    var config = config_1.getConfig();
    var projects = projects_1.getProjects();
    var projectName = (_a = args._[1]) === null || _a === void 0 ? void 0 : _a.toString();
    if (projectName == undefined) {
        throw new commands_1.OrigeenError("In order to open a project, you need to provide its name.", [
            "Provide '<projectName>' after the command name",
        ]);
    }
    log("Project name : '" + projectName + "'");
    log();
    var project = projects.find(function (project) { return project.name === projectName; });
    if (project == undefined) {
        throw new commands_1.OrigeenError("A project named `" + projectName + "` wasn't found.", [
            "Check the spelling",
            "Run the 'projects' command to list all your projects",
        ]);
    }
    var projectPath = project.path;
    debug("Path to Project :");
    debug(projectPath);
    debug();
    var editorPath = config.editorPath;
    if (editorPath == undefined) {
        error("You did not provide the path to your favorite editor.");
        error("You can set it with : \"orgn config editorPath --set <pathToEditor>\"");
        throw new commands_1.OrigeenError("You did not set the path to your favourite code editor", [
            "Set it with: 'origeen config editorPath --set <pathToEditor>"
        ]);
    }
    debug("Path to editor :");
    debug(editorPath);
    debug();
    var command = "\"" + editorPath + "\" \"" + projectPath + "\"";
    debug("Running : '" + command + "'");
    try {
        child_process_1.execSync(command);
    }
    catch (err) {
        throw new commands_1.OrigeenError("There was an error executing the command :\n'" + command + "'", [
            "See the logs to know what happened",
            "Check that the path to your editor is correct",
            "Run the command manually"
        ]);
    }
}
exports.execute = execute;
